==> haskell-hls-class-plugin-2.0.0.0-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-class-plugin-2.0.0.0-KyH1jy8c1I6Ay9F4Y1TMg4
key:                  hls-class-plugin-2.0.0.0-KyH1jy8c1I6Ay9F4Y1TMg4
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5178faa487850078e9c36a5274841cbd
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.0.0.0-KyH1jy8c1I6Ay9F4Y1TMg4
depends:
    aeson-2.1.2.1-DzmMfEZgdOFRIaYChwLwW base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-JnF5xEhGq5wHy9VVk5aF6Q ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-GxU5Jhi7wAV96jhZhqurgN
    ghcide-2.0.0.0-9jzk2UleaT77I2gCKHeLsl
    hls-graph-2.0.0.0-6yvJgXmDZ2v2BSt6ai8HJg
    hls-plugin-api-2.0.0.0-7pdwDVB2KN7L4xV7HfZaob
    lens-5.2.3-BcpyiYLuQbK95py8n8AnSz
    lsp-1.6.0.0-43H1sFFjAlkDJh8oAZNhLp text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-class-plugin-2.0.0.0-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-class-plugin-2.0.0.0-HCnj66ghUIZFeRt0JpqweZ
key:                  hls-class-plugin-2.0.0.0-HCnj66ghUIZFeRt0JpqweZ
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bc6ad7b342abdfa42f66e56277e3c3a7
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.0.0.0-HCnj66ghUIZFeRt0JpqweZ
depends:
    aeson-2.1.2.1-9BF5sjMs3G4H72EdbKHz4V base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-8afQiu2kMl021rKAXFYaei ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-3HLrez0HIbg8SXMPurGetZ
    ghcide-2.0.0.0-Z1KLeLZfFg8FtmrJiLhGf
    hls-graph-2.0.0.0-7rVbCC8fQUhAWis1kOVzXG
    hls-plugin-api-2.0.0.0-2GQwDXq7m4g7sn0hf8cIuZ
    lens-5.2.3-KMe0UA9rcY2CQDwAzcGcMr
    lsp-1.6.0.0-5YaNUX7lMWN8uZML4Uc3LQ text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
